@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2017-01-04'; # DATE
-our $VERSION = '1.46'; # VERSION
+our $DATE = '2017-01-12'; # DATE
+our $VERSION = '1.47'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -1483,9 +1483,25 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         gen_args    => {
                             read_env => 1,
                             script_name => 'sum-nums',
-                            url => '/Perinci/Examples/sum',
+                            url => '/Perinci/Examples/Tiny/sum',
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
+                        argv        => [qw/3/],
+                        exit_code   => 0,
+                        stdout_like => qr/^6$/s,
+                    },
+                    {
+                        tags        => ['env'],
+                        name        => 'default env name prefixed by _ if script name starts with number',
+                        env         => {
+                            _0SUM_NUMS_OPT => '1 2',
+                        },
+                        gen_args    => {
+                            read_env => 1,
+                            script_name => '0sum-nums',
+                            url => '/Perinci/Examples/Tiny/sum',
+                        },
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [qw/3/],
                         exit_code   => 0,
                         stdout_like => qr/^6$/s,
@@ -1499,9 +1515,9 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                         gen_args    => {
                             read_env => 1,
                             script_name => 'sum-nums',
-                            url => '/Perinci/Examples/sum',
+                            url => '/Perinci/Examples/Tiny/sum',
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [qw/--no-env 3/],
                         exit_code   => 0,
                         stdout_like => qr/^3$/s,
@@ -1517,9 +1533,9 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
                             read_env => 1,
                             script_name => 'sum-nums',
                             env_name => 'foo_opt',
-                            url => '/Perinci/Examples/sum',
+                            url => '/Perinci/Examples/Tiny/sum',
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [qw/3/],
                         exit_code   => 0,
                         stdout_like => qr/^18$/s,
@@ -1574,12 +1590,12 @@ _
                         tags        => ['config-file'],
                         name        => 'attr:config_dirs',
                         gen_args    => {
-                            url => '/Perinci/Examples/noop2',
+                            url => '/Perinci/Examples/Tiny/noop2',
                             script_name => 'prog',
                             read_config => 1,
                             config_dirs => [$tempdir],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [],
                         stdout_like => qr/^a=101\nb=201\nc=\nd=\ne=$/,
                     },
@@ -1587,13 +1603,13 @@ _
                         tags        => ['config-file'],
                         name        => 'attr:config_filename',
                         gen_args    => {
-                            url => '/Perinci/Examples/noop2',
+                            url => '/Perinci/Examples/Tiny/noop2',
                             script_name => 'prog',
                             read_config => 1,
                             config_dirs => [$tempdir],
                             config_filename => 'prog2.conf',
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [],
                         stdout_like => qr/^a=104\nb=\nc=\nd=\ne=$/,
                     },
@@ -1601,13 +1617,13 @@ _
                         tags        => ['config-file'],
                         name        => 'attr:config_filename (hash record)',
                         gen_args    => {
-                            url => '/Perinci/Examples/noop2',
+                            url => '/Perinci/Examples/Tiny/noop2',
                             script_name => 'prog',
                             read_config => 1,
                             config_dirs => [$tempdir],
                             config_filename => [{filename=>'prog4.conf', section=>'prog'}, 'prog2.conf'],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [],
                         stdout_like => qr/^a=104\nb=303\nc=\nd=\ne=$/,
                     },
@@ -1615,13 +1631,13 @@ _
                         tags        => ['config-file'],
                         name        => 'attr:config_filename (hash record) + --config-profile',
                         gen_args    => {
-                            url => '/Perinci/Examples/noop2',
+                            url => '/Perinci/Examples/Tiny/noop2',
                             script_name => 'prog',
                             read_config => 1,
                             config_dirs => [$tempdir],
                             config_filename => [{filename=>'prog4.conf', section=>'prog'}, 'prog2.conf'],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [qw/--config-profile profile1/],
                         stdout_like => qr/^a=104\nb=307\nc=\nd=\ne=$/,
                     },
@@ -1629,12 +1645,12 @@ _
                         tags        => ['config-file'],
                         name        => 'common option: --no-config',
                         gen_args => {
-                            url => '/Perinci/Examples/noop2',
+                            url => '/Perinci/Examples/Tiny/noop2',
                             script_name => 'prog',
                             read_config =>1,
                             config_dirs => [$tempdir],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [qw/--no-config/],
                         stdout_like => qr/^a=\nb=\nc=\nd=\ne=$/,
                     },
@@ -1642,12 +1658,12 @@ _
                         tags        => ['config-file'],
                         name        => 'common option: --config-path',
                         gen_args    => {
-                            url => '/Perinci/Examples/noop2',
+                            url => '/Perinci/Examples/Tiny/noop2',
                             script_name => 'prog',
                             read_config =>1,
                             #config_dirs => [$tempdir],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => ['--config-path', "$tempdir/prog.conf"],
                         stdout_like => qr/^a=101\nb=201\nc=\nd=\ne=$/,
                     },
@@ -1655,12 +1671,12 @@ _
                         tags        => ['config-file'],
                         name        => 'common option: --config-profile',
                         gen_args    => {
-                            url => '/Perinci/Examples/noop2',
+                            url => '/Perinci/Examples/Tiny/noop2',
                             script_name => 'prog',
                             read_config =>1,
                             config_dirs => [$tempdir],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [qw/--config-profile=profile1/],
                         stdout_like => qr/a=111\nb=201\nc=\nd=201\ne=$/,
                     },
@@ -1668,12 +1684,12 @@ _
                         tags        => ['config-file'],
                         name        => 'unknown config profile -> error',
                         gen_args    => {
-                            url => '/Perinci/Examples/noop2',
+                            url => '/Perinci/Examples/Tiny/noop2',
                             script_name => 'prog',
                             read_config =>1,
                             config_dirs => [$tempdir],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [qw/--config-profile=foo/],
                         exit_code   => 112,
                     },
@@ -1681,12 +1697,12 @@ _
                         tags        => ['config-file'],
                         name => 'unknown config profile but does not read config -> ok',
                         gen_args    => {
-                            url => '/Perinci/Examples/noop2',
+                            url => '/Perinci/Examples/Tiny/noop2',
                             script_name => 'foo',
                             read_config =>1,
                             config_dirs => [$tempdir],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [qw/--config-profile=bar/],
                         stdout_like => qr/^a=\nb=\nc=\nd=\ne=$/,
                     },
@@ -1699,7 +1715,7 @@ _
                     #        $r->{ignore_missing_config_profile_section} = 1;
                     #    },
                     #    gen_args => {...},
-                    #    #inline_gen_args => {...},
+                    #    inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                     #argv => [qw/--config-profile=bar/],
                     #stdout_like => qr/^a=101\nb=201\nc=\nd=\ne=$/,
                     #}
@@ -1707,15 +1723,15 @@ _
                         tags        => ['config-file', 'subcommand'],
                         name        => 'subcommand',
                         gen_args    => {
-                            url => '/Perinci/Examples/',
+                            url => '/Perinci/Examples/Tiny/',
                             subcommands => {
-                                'subcommand1' => '/Perinci/Examples/noop2',
+                                'subcommand1' => '/Perinci/Examples/Tiny/noop2',
                             },
                             script_name => 'prog',
                             read_config =>1,
                             config_dirs => [$tempdir],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [qw/subcommand1/],
                         stdout_like => qr/^a=102\nb=201\nc=201\nd=\ne=$/,
                     },
@@ -1724,15 +1740,15 @@ _
                         tags        => ['config-file', 'subcommand'],
                         name        => 'subcommand + --config-profile',
                         gen_args => {
-                            url => '/Perinci/Examples/',
+                            url => '/Perinci/Examples/Tiny/',
                             subcommands => {
-                                'subcommand1' => '/Perinci/Examples/noop2',
+                                'subcommand1' => '/Perinci/Examples/Tiny/noop2',
                             },
                             script_name => 'prog',
                             read_config => 1,
                             config_dirs => [$tempdir],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [qw/--config-profile=profile1 subcommand1/],
                         stdout_like => qr/^a=121\nb=201\nc=201\nd=201\ne=$/,
                     },
@@ -1740,12 +1756,12 @@ _
                         tags        => ['config-file'],
                         name        => 'array-ify if argument is array',
                         gen_args    => {
-                            url => '/Perinci/Examples/sum',
+                            url => '/Perinci/Examples/Tiny/sum',
                             script_name => 'sum',
                             read_config => 1,
                             config_dirs => [$tempdir],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [qw//],
                         stdout_like => qr/^0$/,
                     },
@@ -1753,15 +1769,15 @@ _
                     # TODO array-ify common option
 
                     {
-                        tags        => ['config-file'],
+                        tags        => ['config-file', 'config-file-sets-common-options'],
                         name        => 'can also set common option',
                         gen_args    => {
-                            url => '/Perinci/Examples/noop2',
+                            url => '/Perinci/Examples/Tiny/noop2',
                             script_name => 'prog3',
                             read_config => 1,
                             config_dirs => [$tempdir],
                         },
-                        #inline_gen_args => {...},
+                        inline_gen_args => {load_module=>['Perinci::Examples::Tiny']},
                         argv        => [],
                         stdout_like => qr/^"a=101\\nb=\\nc=\\nd=\\ne="/,
                     },
@@ -1792,7 +1808,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.46 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2017-01-04.
+This document describes version 1.47 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2017-01-12.
 
 =for Pod::Coverage ^(pericmd_ok)$
 
